@@ -30,9 +30,9 @@ from knack.util import CLIError
 
 from azure.cli.core.commands.client_factory import ENV_ADDITIONAL_USER_AGENT
 from azure.cli.core._config import DEFAULTS_SECTION
-from azure.cli.core._environment import get_config_dir
 from azure.cli.core._profile import _SUBSCRIPTION_NAME, Profile
 from azure.cli.core._session import ACCOUNT, CONFIG, SESSION
+from azure.cli.core.api import get_config_dir
 from azure.cli.core.util import handle_exception
 
 from . import __version__
@@ -660,13 +660,12 @@ class AzInteractiveShell(object):
 
             self.last_exit = 0
             if result and result.result is not None:
-                from azure.cli.core._output import OutputProducer
                 if self.output:
                     self.output.write(result)
                     self.output.flush()
                 else:
-                    formatter = OutputProducer.get_formatter(self.cli_ctx.invocation.data['output'])
-                    OutputProducer(formatter=formatter).out(result)
+                    formatter = self.cli_ctx.output.get_formatter(self.cli_ctx.invocation.data['output'])
+                    self.cli_ctx.output.out(result, formatter=formatter)
                     self.last = result
 
         except Exception as ex:  # pylint: disable=broad-except
